@@ -13,6 +13,7 @@ has '_tp_result' =>
 (
     is => "rw",
     isa => "Maybe[TAP::Parser::Result]",
+    init_arg => "event",
     handles => [qw(
         comment
         description
@@ -47,16 +48,6 @@ delegates some methods to it, and defines some of its own methods.
 
 =cut
 
-sub _init
-{
-    my $self = shift;
-    my $args = shift;
-
-    $self->_tp_result($args->{event});
-
-    return 0;
-}
-
 =head2 $event->is_pass()
 
 Returns whether the event can be considered a passed event. Always returns a
